<?php

namespace App\Http\Controllers\Api\Auth;

use App\Models\Result;
use App\Models\UniversityCode;
use App\Models\Zone;
use App\Services\ApiCommonResponseService;
use App\Http\Controllers\Controller;
use App\Services\NotificationService;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Tymon\JWTAuth\Exceptions\JWTException;
use Tymon\JWTAuth\Facades\JWTAuth;


class LoginController extends Controller
{

    protected $response;

    public function __construct()
    {
        /*$this->middleware('jwt.auth')->only(['logout']);*/
        $this->apiResponse = new ApiCommonResponseService();
    }

    public function login(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'email' => 'required',
            'password' => 'required',

        ]);

        if ($validator->fails()) {

            $message = $validator->errors()->first();
            return $this->apiResponse->error_response('500', 'Validation Error', $validator->errors());

        }


        // grab credentials from the request

        $credentials = $request->only('email', 'password');

        $activated_user = User::where('email', $request->email)->where('email_status', 1)
            ->where('active_status', '=', 1)
            ->whereNotNull('password')
            ->first();

        if ($activated_user) {

            try {
                // attempt to verify the credentials and create a token for the user
                $customClaims = ['url' => env('APP_URL')];
                if (!$token = JWTAuth::attempt($credentials)) {
                    return $this->apiResponse->error_response(500, 'Invalid Credentials', 'Wrong Credentials.Try with correct login credentials.');


                }
            } catch (JWTException $e) {
                // something went wrong whilst attempting to encode the token
                return response()->json([
                    'success' => 'false',
                    'code' => 1003,
                    'message' => 'Could not create token.'
                ], 500);
            }


            return $this->apiResponse->success_response(200, 'Login Successfull', ['token' => $token]);

        } else {

            $user_exist = User::where('email', $request->email)
                ->where('email_status', 0)
                ->whereNotNull('password')
                ->first();
            //dd($user_exist);

            if ($user_exist) {
                return $this->apiResponse->error_response(500, 'You are not verified by Mail yet.Kindly Check your Mail',
                    'You are not verified by Mail yet.Kindly Check your Mail');

            } else {
                $approver_exist = User::where('email', $request->email)
                    ->where('email_status',1)
                    ->whereNotNull('password')
                    ->first();
                //dd($approver_exist);

                if ($approver_exist) {

                    return $this->apiResponse->error_response(500, 'Your profile is not still reviewed by us.Kindly wait for approval .After approval you will get a confirmation email .Try login after confirmation  ',
                        'Your profile is not still reviewed by us.Kindly wait for approval .After approval you will get a confirmation email .Try login after confirmation');
                } else {


                    return $this->apiResponse->error_response(500, 'Invalid Credentials', 'Invalid Credentials');
                }


            }
        }

    }

    public function authenticateSocial(Request $request)
    {

        $provider_id = $request->provider_id;
        $provider_name = $request->provider_name;

        $user =
            User::where('provider_id', $provider_id)
                ->where('provider_name', $provider_name)->get()->first();

        if (count($user)) {
            try {

                // attempt to create a token for the user
                $customClaims = ['url' => env('APP_URL')];
                $token = JWTAuth::fromUser($user, $customClaims);

            } catch (JWTException $e) {
                // something went wrong whilst attempting to encode the token
                return response()->json([
                    'success' => 'false',
                    'code' => 1003,
                    'message' => 'Could not create token.'
                ], 500);
            }

            // all good so return the token
            return array(
                'success' => 'true',
                'code' => 1000,
                "token_type" => "Bearer",
                "expires_in" => 31536000,
                "access_token" => $token
            );

        } else {

            return response()->json([
                'success' => 'false',
                'code' => 1003,
                'message' => 'Invalid Credentials'
            ], 401);

        }


    }


    public function logout(Request $request)
    {

        /*$validation = Validator::make($request->all(), [
                "notification_token" => "required",
            ]
        );

        if ($validation->fails()) {

            $message = $validation->errors()->first();
            return $this->response->message($message)->error_response();

        }

        NotificationService::deleteNotificationToken($request->notification_token);

        $message = "Logged out successfully.";
        return $this->response->message($message)->success_response([]);*/

        try {

            $token = JWTAuth::parseToken();
            //dd($token);
            JWTAuth::invalidate($token);

            return $this->apiResponse->success_response(200, 'You have successfully logged out.', []);

        } catch (\Exception $e) {
            // something went wrong whilst attempting to encode the token
            return $this->apiResponse->error_response(200, 'Internal error', 'Failed to Logout.Please, try again');
        }

    }

    public function getLoggedInUser(Request $request)
    {
        $user = JWTAuth::parseToken()->authenticate();
        $formatted_data['user_name'] = $user->user_name;
        $formatted_data['father_name'] = $user->father_name;
        $formatted_data['mother_name'] = $user->mother_name;
        $formatted_data['company'] = $user->company;
        $formatted_data['tth_id'] = $user->tth_id;
        $formatted_data['email'] = $user->email;
        $formatted_data['designation'] = $user->designation;
        $formatted_data['image'] = $user->image;
        $formatted_data['phone'] = $user->phone;
        $formatted_data['address'] = $user->address;
        $formatted_data['user_type'] = $user->user_type;
        $formatted_data['reference_id']=$user->reference_id;
        $formatted_data['bkash']=$user->bkash_transaction_no;

        if($user->zone_id){
            $formatted_data['zone'] = Zone::find($user->zone_id);
        }
        else{
            $formatted_data['zone'] = [
                'id' => 0 ,
                 'name' => null
            ];
        }
        if($user->institute_name){
            $formatted_data['university'] = UniversityCode::find($user->institute_name);
        }
        else{
            $formatted_data['university'] = [
                'id' => 0 ,
                'university' => $user->university_name
            ];
        }
        $formatted_data['result'] = $this->getResult($user->id);
        return response()->json(['user' => $formatted_data]);
    }
    public function getResult($user_id){
        $result = Result::where('participant_id', $user_id)->first();
        $data = [];
        if(!$result){
            $data = [
                'mcq' => 'Not Attended / Examined Yet',
                'video' => 'Not Attended / Examined Yet',
                'physical' => 'Not Attended / Examined Yet',
            ];
        }
        else{
            $data = [
                'mcq' => $result->mcq_exam_marks == -1 ? 'Not Attended / Examined yet' : $result->mcq_exam_marks,
                'video' => $result->video_audition_marks == 0 ? 'Not Attended / Examined yet' : $result->video_audition_marks,
                'physical' => $result->physical_audition_marks == 0 ? 'Not Attended / Examined yet' : $result->physical_audition_marks,
            ];
        }
        return $data;
    }

}
