<?php

namespace App\Http\Controllers\Api\Auth;

use App\Jobs\SendVerifyEmail;
use App\Mail\VerifyEmail;
use App\Models\AdminUser;
use App\Services\ApiCommonResponseService;
use App\Services\ImageUploadService;
use App\Services\TthIdGenerator;
use App\Services\UserService;
use App\User;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Str;

class RegisterController extends Controller
{


    private $apiResponse;

    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();

    }

    public function registerUser(Request $request)
    {

        $validator = Validator::make($request->all(),
            [
                'user_name'=>'required|unique:mysql.users',
                'user_type' => 'required',
                'father_name'=>'required_if:user_type,==,4',
                'mother_name'=>'required_if:user_type,==,4',
                'institute_name'=>'required_if:user_type,==,4',
                'email' => 'required|string|email|max:255|unique:mysql.users',
                'phone'=>'required_if:user_type,==,4|regex:/(^(?:\+?88)?01[0-9]\d{8}$)/',
                'password' => 'required|string|min:6|confirmed',
                'zone_id' => 'required_if:user_type,==,4',
                'bkash_transaction_id' => 'required_if:user_type,==,4',
                'season'=>'required_if:user_type,==,4',
            ]
        );



        if ($validator->fails()) {


            return $this->apiResponse->error_response('400', 'Validation Error', $validator->errors());


        } else {
            //dd($request);

            $user_type = $request->user_type;
            $session = $request->tth_season;
            $institute_id = $request->institute_name;

            $tth_id ='';

            if($user_type == 4){
                $tth_id = TthIdGenerator::createTthId($session,$institute_id);

            }


            $image_url="";

            if(isset($request->image)) {

                $file = $request->image;
                $path = 'images/tth/user/';
                $title = 'pp_image_';
                $image_url = ImageUploadService::fileUploadWithDirCreate($path, $file, $title);

            }
            if(isset($request->image_link)){
                $image_url = $request->image_link;
            }
            $company_image_url="";
            if(isset($request->company_logo)) {

                $file = $request->company_logo;
                // save the image update image url
                $path = 'images/tth/user/';
                $title = 'pp_image_';
                $company_image_url = ImageUploadService::fileUploadWithDirCreate($path, $file, $title);

            }
            $is_admin = UserService::checkIfAdmin($user_type);
            $new_user = User::create([
                'user_name' => $request->user_name,
                'email' => $request->email,
                'tth_season' => $request->tth_season,
                'father_name' => $request->father_name,
                'mother_name' => $request->mother_name,
                'tth_id' => $tth_id,
                'institute_name' => $request->institute_name,
                'password' => Hash::make($request->password),
                'image' => $image_url,
                'f_name' => $request->f_name,
                'l_name' => $request->l_name,
                'phone' => $request->phone,
                'address' => $request->address,
                'designation' => $request->designation,
                't_tth_season' => $request->t_tth_season,
                'company' => $request->company,
                'gender' => $request->gender,
                'user_type' => $user_type,
                'email_status'=> $is_admin,
                'verify_token' => Str::random(40),
                'active_status' => $is_admin,
                'company_logo' => $company_image_url,
                'is_admin' => $is_admin,
                'bkash_transaction_no' => $request->bkash_transaction_id,
                'zone_id' => $request->zone_id,
                'reference_id' => $request->reference_id,
                'university_name' => $request->university_name
            ]);

            try {
                $this->sendVerificationEmail($new_user);
            } catch (\Exception $e) {
            }

            return $this->apiResponse->success_response('200', 'Please Verify Your Email', $new_user->id);

        }


    }

    public function sendVerificationEmail(User $user)
    {
        dispatch(new SendVerifyEmail($user));
    }


    public function verifyEmail($email, $verifyToken)
    {
        $requested_user = User::where('email', $email)
            ->where('verify_token', $verifyToken)
            ->where('email_status', 0)
            ->first();

        if ($requested_user) {

            $requested_user->email_status = 1;
            $requested_user->verify_token = null;
            $requested_user->save();

            // follow vinndo users start


            session()->flash('message', 'Email has been verified successfully.');
            return Redirect::to('https://textiletalenthunt.com/login?email_status=1&email='.$requested_user->email);

        } else {
            $user_exist = User::where('email', $email)
                ->where('verify_token', $verifyToken)
                ->where('email_status', 1)
                ->first();
            if ($user_exist) {

                if ($user_exist->status) {
                    session()->flash('error', 'Email already verified. Try to log in.');
                    return Redirect::to('https://tth-font-web.herokuapp.com/');

                } else {
                    return Redirect::to('https://tth-font-web.herokuapp.com/login?email_status=1');
                }

            } else {
                session()->flash('error', 'Email not verified. Invalid Credentials.');
            }
            return redirect()->route('login');

        }
    }
    public function ResendEmail(Request $request)
    {
      $user= User::where('email',$request->email)->first();
      //dd($user);
      if($user==null)
      {
          return $this->apiResponse->error_response('200','No User Found For This Email','Please Register Your Email');
      }
      else
      {
         $user->update(
         [
             'verify_token'=>Str::random(40)
         ]
         ) ;
      }
        try {
            $this->sendVerificationEmail($user);
        } catch (\Exception $e) {
        }

        return $this->apiResponse->success_response('200', 'Please Verify Your Email', $user->id);



    }


}
