<?php

namespace App\Http\Controllers\Api;

use App\Models\Exam;
use App\Models\Question;
use App\Services\ApiCommonResponseService;
use App\Services\ExamService;
use App\Services\QuestionService;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class QuestionController extends Controller
{
    private $apiResponse , $questionService;
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();
        $this->questionService = new QuestionService();

    }
    public function store(Request $request){
        $validation = Validator::make($request->all(), [
            'exam_id' => 'required',
            'question' => 'required',
            'options' => 'required',
            'correct_answer' => 'required',
            'difficulty' => 'required'
        ]);
        if ($validation->fails()) {
            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }
        $exam = $this->questionService->create($request);
        return $this->apiResponse->success_response('200','Content Successfully Updated', $exam);

    }
    public function update(Request $request){
        $validation = Validator::make($request->all(), [
            'id' => 'required',
            'question' => 'required',
            'options' => 'required',
            'correct_answer' => 'required',
            'difficulty' => 'required'

        ]);
        if ($validation->fails()) {
            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }
        $exam = $this->questionService->update($request);
        return $this->apiResponse->success_response('200','Content Successfully Updated', $exam);

    }
    public function getList(Request $request){
        $questions = Question::where('exam_id', $request->exam_id)->get();
        return $this->apiResponse->success_response('200','Content Successfully Updated', $questions);

    }
    public function delete(Request $request){
        $this->questionService->delete($request);
        return $this->apiResponse->success_response('200','Content Successfully Deleted', []);

    }
    public function get(Request $request){
        $exam = $this->examService->get($request);
        return $this->apiResponse->success_response('200','Content Successfully Updated', $exam);

    }
    public function getQuestionsForExam(Request $request){
        $exam =  Exam::find($request->id);
        $current_time = Carbon::now();
        $start_time = Carbon::parse($exam->exam_date.' '.$exam->exam_start_time);
        $end_time = Carbon::parse($exam->exam_date.' '.$exam->exam_end_time);
        if(!$current_time->between($start_time, $end_time , true)){
            return $this->apiResponse->error_response('400', 'Exam not Running', 'Exam is not running');
        }
        else{
            $data = $this->questionService->getQuestionsForExam($request);
            return $this->apiResponse->success_response('200','Question updated succesfully', $data);


        }

    }
}
