<?php

namespace App\Http\Controllers\Api;

use App\Services\ApiCommonResponseService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Gate;
use Illuminate\Support\Facades\Validator;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class RoleController extends Controller
{

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    private $apiResponse;
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();

    }


    public function index()
    {



        $roles = Role::all();
        $data=[];
        foreach ($roles as $role)
        {
            $data[]=[
              'id'=>$role->id,
              'name'=>$role->name,
            ];
        }

        return $this->apiResponse->success_response('200','All Roles Information',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if (! Gate::allows('Role-Manage')) {
            return abort(401);
        }

        $permissions = Permission::get();
        return view('admin.users.roles.create',compact('permissions'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        //dd($request->permissions);



        $validation = Validator::make($request->all(), [


            'name' => 'required|unique:roles,name',
            'permissions' => 'required',
        ]);



        if ($validation->fails()) {


            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());


        }

        $role = Role::create([
            'name' => $request->name,
            'guard_name' => 'web'
        ]);


        //dd($request->permissions);
       $t= $role->givePermissionTo($request->permissions);
       //dd($t);



        return $this->apiResponse->success_response('201', 'Succesfully Store', $role);







    }
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if (!Gate::allows('Role-Manage')) {
            return abort(401);
        }

        $role = Role::findOrFail($id);

        $rolePermissions = $role->permissions()->pluck('name');


        return view('admin.users.roles.show', compact('role', 'rolePermissions'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request)
    {

        $role = Role::find($request->id);
        $permissions = Permission::get();

        $rolePermissions = $role->permissions()->get();

        //dd($rolePermissions);

        $data=[];
        foreach($rolePermissions as $permission)
        {
            $data[]=[
                'name'=>$permission->name
            ];
        }

        //dd($data);
        return $this->apiResponse->success_response('201', 'Succesfully Store', $data);

        //return view('admin.users.roles.edit',compact('role','permissions','rolePermissions'));
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if (! Gate::allows('Role-Manage')) {
            return abort(401);
        }

        $this->validate($request, [
            'name' => 'required',
            'permissions' => 'required',
        ]);

        $role = Role::findOrFail($id);
        $role->update([
            'name' => $request->name
        ]);
        $permissions = $request->input('permissions') ? $request->input('permissions') : [];
        $role->syncPermissions($permissions);

        return redirect()->route('roles.index')
            ->with('success','Role updated successfully');
    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if (! Gate::allows('Role-Manage')) {
            return abort(401);
        }

        DB::table("roles")->where('id',$id)->delete();
        return redirect()->route('roles.index')
            ->with('success','Role deleted successfully');
    }
}
