<?php

namespace App\Http\Controllers\Api;

use App\Jobs\SendRegCongratulationMail;
use App\Models\Result;
use App\Models\TthUser;
use App\Models\UniversityCode;
use App\Models\Zone;
use App\Services\ApiCommonResponseService;
use App\Services\ImageUploadService;
use App\Services\TthIdGenerator;
use App\Services\UserService;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Gate;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;
use Tymon\JWTAuth\Facades\JWTAuth;


class UserController extends Controller
{

    private $apiResponse, $userService, $result_per_page = 20;

    public function __construct()
    {
        $this->userService = new UserService();
        $this->apiResponse = new ApiCommonResponseService();

    }

    public function create(Request $request)
    {

        $validator = Validator::make($request->all(),
            [
                'email' => 'required|unique:users,email',
                'user_name' => 'required',
                'password' => 'required',
                'user_type' => 'required'

            ]);

        if ($validator->fails()) {
            $message = $validator->errors()->first();
            return $this->apiResponse->error_response(400, 'Validation Error', $message);
        }

        try {

            $user_type = $request->user_type;
            $session = $request->tth_season;
            $institute_id = $request->institute_name;

            $tth_id = '';

            if ($user_type == 4) {
                $tth_id = TthIdGenerator::createTthId($session, $institute_id);

            }

            $file = $request->image;
            // save the image update image url
            $path = 'images/tth/user/';
            $title = 'pp_image_';
            $image_url = ImageUploadService::fileUploadWithDirCreate($path, $file, $title);

            $user_creation_info = User::create([
                'user_name' => $request->user_name,
                'email' => $request->email,
                'tth_season' => $request->tth_season,
                'father_name' => $request->father_name,
                'mother_name' => $request->mother_name,
                'tth_id' => $tth_id,
                'institute_name' => $request->institute_name,
                'password' => Hash::make($request->password),
                'image' => $image_url,
                'f_name' => $request->f_name,
                'l_name' => $request->l_name,
                'phone' => $request->phone,
                'address' => $request->address,
                'designation' => $request->designation,
                't_tth_season' => $request->t_tth_season,
                'company' => $request->company,
                'gender' => $request->gender,
                'user_type' => $user_type,
                'email_status' => 1,
                'active_status' => 1
            ]);


            return $this->apiResponse->success_response(200, 'User created successfully', $user_creation_info);
        } catch (\Exception $e) {
            return $this->apiResponse->error_response(200, 'Failed to create user. Please try again later', $e->getMessage());
        }
    }


    public function update(Request $request)
    {
        $validation = Validator::make($request->all(), [
            'user_name' => 'required',
            'father_name' => 'required',
            'mother_name' => 'required',
        ]);

        if ($validation->fails()) {
            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }
        $user = auth()->user();
        if (isset($user)) {
            $user = User::find($user->id);
            if (!empty($user)) {

                $flag = $this->userService->update($request, $user);
                return $this->apiResponse->success_response('200', 'User Successfully Updated', $flag);
            } else {
                return $this->apiResponse->error_response('400', 'No user Found in Database', $user);
            }
        }
        return $this->apiResponse->error_response('400', 'No user Found ', $user);
    }

    public function delete(Request $request)
    {

        $id = $request->id;
        $is_exists = User::find($id);

        if (!$is_exists) {

            $code = '204';
            $message = 'Content Not Found';

            return $this->apiResponse->error_response($code, $message, 'Content Not Found');

        }

        $is_exists->delete();

        return $this->apiResponse->success_response('200', 'Content Successfully Deleted', $is_exists);

    }

    public function index()
    {

        $all_data_users = User::all();
        return $this->apiResponse->success_response('200', 'Data Is Ready To Show', $all_data_users);
    }

    public function getRegistrationUserTypes()
    {
        $user_types = TthUser::where('is_admin', false)->get();
        return $this->apiResponse->success_response('200', 'User Types are Retrived', $user_types);


    }

    public function getAdminUserTypes()
    {
        $user_types = TthUser::where('is_admin', true)->get();
        return $this->apiResponse->success_response('200', 'User Types are Retrived', $user_types);


    }

    public function approverlist(Request $request)
    {
        $page_number = $request->page_number;
        if (!$page_number)
            $page_number = 1;
        $take = $this->result_per_page;
        $skip = ($page_number - 1) * $take;
        if ($request->search && $request->zone_id) {
            //return $request->search;
            $users = User::where('email_status', '=', 1)->where('active_status', '=', 1)->where('user_type', 4)->where('zone_id', $request->zone_id)->where(function ($q) use ($request) {
                return $q->where('user_name', 'like', '%' . $request->search . '%')->orwhere('tth_id', 'like', '%' . $request->search . '%');
            })
                ->with('zone')->skip($skip)->take($take)->get();
            $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 1)->where('user_type', 4)->where('zone_id', $request->zone_id)->where(function ($q) use ($request) {
                return $q->where('user_name', 'like', '%' . $request->search . '%')->orwhere('tth_id', 'like', '%' . $request->search . '%');
            })->with('zone')->skip($skip)->take($take)->count();


        } elseif ($request->search) {
            $users = User::where('email_status', '=', 1)->where('active_status', '=', 1)->where('user_type', 4)->
            where(function ($q) use ($request) {
                return $q->where('user_name', 'like', '%' . $request->search . '%')->orwhere('tth_id', 'like', '%' . $request->search . '%');
            })->with('zone')->skip($skip)->take($take)->get();
            $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 1)->where('user_type', 4)->where(function ($q) use ($request) {
                return $q->where('user_name', 'like', '%' . $request->search . '%')->orwhere('tth_id', 'like', '%' . $request->search . '%');
            })->with('zone')->skip($skip)->take($take)->count();
        } elseif ($request->zone_id) {
            $users = User::where('email_status', '=', 1)->where('active_status', '=', 1)->where('user_type', 4)->where('zone_id', $request->zone_id)->with('zone')->skip($skip)->take($take)->get();
            $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 1)->where('user_type', 4)->where('zone_id', $request->zone_id)->with('zone')->skip($skip)->take($take)->count();
        } else {
            $users = User::where('email_status', '=', 1)->where('active_status', '=', 1)->where('user_type', 4)->with('zone')->skip($skip)->take($take)->get();
            $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 1)->where('user_type', 4)->count();
        }


        $formated_data = $this->userService->approverlist($users);
        $formated_data = $this->apiResponse->pagination($formated_data, $page_number, $total_count, $this->result_per_page);
        return $this->apiResponse->success_response('200', 'Waiting List of Admin Approval', $formated_data);


    }

    public function upApproverlist(Request $request)
    {
        $page_number = $request->page_number;
        if (!$page_number)
            $page_number = 1;
        $take = $this->result_per_page;
        $skip = ($page_number - 1) * $take;
        if ($request->search && $request->zone_id) {
            //return $request->search;
            $users = User::where('email_status', '=', 1)->where('active_status', '=', 0)->where('user_type', 4)->where('zone_id', $request->zone_id)->where(function ($q) use ($request) {
                return $q->where('user_name', 'like', '%' . $request->search . '%')->orwhere('tth_id', 'like', '%' . $request->search . '%');
            })
                ->with('zone')->skip($skip)->take($take)->get();
            $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 0)->where('user_type', 4)->where('zone_id', $request->zone_id)->where(function ($q) use ($request) {
                return $q->where('user_name', 'like', '%' . $request->search . '%')->orwhere('tth_id', 'like', '%' . $request->search . '%');
            })->with('zone')->skip($skip)->take($take)->count();


        } elseif ($request->search) {
            $users = User::where('email_status', '=', 1)->where('active_status', '=', 0)->where('user_type', 4)->
            where(function ($q) use ($request) {
                return $q->where('user_name', 'like', '%' . $request->search . '%')->orwhere('tth_id', 'like', '%' . $request->search . '%');
            })->with('zone')->skip($skip)->take($take)->get();
            $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 0)->where('user_type', 4)->where(function ($q) use ($request) {
                return $q->where('user_name', 'like', '%' . $request->search . '%')->orwhere('tth_id', 'like', '%' . $request->search . '%');
            })->with('zone')->skip($skip)->take($take)->count();
        } elseif ($request->zone_id) {
            $users = User::where('email_status', '=', 1)->where('active_status', '=', 0)->where('user_type', 4)->where('zone_id', $request->zone_id)->with('zone')->skip($skip)->take($take)->get();
            $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 0)->where('user_type', 4)->where('zone_id', $request->zone_id)->with('zone')->skip($skip)->take($take)->count();
        } else {
            $users = User::where('email_status', '=', 1)->where('active_status', '=', 0)->where('user_type', 4)->with('zone')->skip($skip)->take($take)->get();
            $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 0)->where('user_type', 4)->count();
        }

        $total_count = User::where('email_status', '=', 1)->where('active_status', '=', 0)->count();
        $formated_data = $this->userService->approverlist($users);
        $formated_data = $this->apiResponse->pagination($formated_data, $page_number, $total_count, $this->result_per_page);
        return $this->apiResponse->success_response('200', 'Waiting List of Admin Approval', $formated_data);

    }


    public function approve(Request $request)
    {

        {
            $user = User::with('zone')->find($request->id);
            $user->update([
                'active_status' => 1
            ]);

            SendRegCongratulationMail::dispatch($user);
            $users = User::with('institute')->where('email_status', '=', 1)->where('active_status', '=', 0)->get();
            $formated_data = $this->userService->approverlist($users);
            return $this->apiResponse->success_response('200', 'User Approved Succesfully', $formated_data);
        }


    }

    public function unapprove(Request $request)
    {

        {
            $user = User::with('zone')->find($request->id);
            $user->update([
                'active_status' => 0
            ]);
            $users = User::with('institute')->where('email_status', '=', 1)->where('active_status', '=', 0)->get();
            $formated_data = $this->userService->approverlist($users);

            return $this->apiResponse->success_response('200', 'User Approved Succesfully', $formated_data);
        }


    }


    public function userDelete(Request $request)
    {
        $kelu = User::find($request->id);
        if ($kelu == null) {
            return $this->apiResponse->success_response('200', 'Already Deleted No data found', 'Abar ki??');


        }

        $kelu->delete();
        return $this->apiResponse->success_response('200', 'Kelu 2r User Delete hoise', 'Mara kha kelu');


    }

    public function getAdminList()
    {
        $users = User::with('UserType')->where('is_admin', '=', 1)->get();
        $data = [];
        foreach ($users as $user) {
            $data[] = [
                'id' => $user->id,
                'user_name' => $user->user_name,
                'email' => $user->email,
                'company' => $user->company,
                'admin_type' => $user->UserType->name
            ];
        }

        return $this->apiResponse->success_response('200', 'Waiting List of Admin Approval', $data);

    }

    public function getUserInfo(Request $request)
    {
        $user = User::find($request->user_id);
        $formatted_data['user_name'] = $user->user_name;
        $formatted_data['father_name'] = $user->father_name;
        $formatted_data['mother_name'] = $user->mother_name;
        $formatted_data['tth_id'] = $user->tth_id;
        $formatted_data['company'] = $user->company;
        $formatted_data['email'] = $user->email;
        $formatted_data['designation'] = $user->designation;
        $formatted_data['image'] = $user->image;
        $formatted_data['phone'] = $user->phone;
        $formatted_data['address'] = $user->address;
        $formatted_data['status'] = $user->active_status;
        $formatted_data['reference_id'] = $user->reference_id;
        $formatted_data['bkash'] = $user->bkash_transaction_no;
        if ($user->zone_id) {
            $formatted_data['zone'] = Zone::find($user->zone_id);
        } else {
            $formatted_data['zone'] = [
                'id' => 0,
                'name' => null
            ];
        }
        if ($user->institute_name) {
            $formatted_data['university'] = UniversityCode::find($user->institute_name);
        } else {
            $formatted_data['university'] = [
                'id' => 0,
                'university' => $user->university_name
            ];
        }
        $formatted_data['result'] = $this->getResult($request->user_id);
        return response()->json(['user' => $formatted_data]);
    }

    public function getResult($user_id){
        $result = Result::where('participant_id', $user_id)->first();
        $data = [];
        if(!$result){
            $data = [
                'mcq' => 'Not Attended / Examined Yet',
                'video' => 'Not Attended / Examined Yet',
                'physical' => 'Not Attended / Examined Yet',
            ];
        }
        else{
            $data = [
                'mcq' => $result->mcq_exam_marks == -1 ? 'Not Attended / Examined yet' : $result->mcq_exam_marks,
                'video' => $result->video_audition_marks == 0 ? 'Not Attended / Examined yet' : $result->video_audition_marks,
                'physical' => $result->physical_audition_marks == 0 ? 'Not Attended / Examined yet' : $result->physical_audition_marks,
            ];
        }
        return $data;
    }

}
