<?php

namespace App\Http\Middleware;

use App\Services\ApiCommonResponseService;
use Closure;
use Exception;
use Tymon\JWTAuth\Facades\JWTAuth;
use Tymon\JWTAuth\Http\Middleware\BaseMiddleware;

class JwtMiddleware extends BaseMiddleware
{
    private $apiResponse;

    /**
     * Handle an incoming request.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  \Closure $next
     * @return mixed
     */

    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();
    }

    public function handle($request, Closure $next)
    {
        try {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return $this->apiResponse->error_response(200, 'User Not Found', ['code' => 301, 'message' => 'User Not Found']);
            }
        } catch (Exception $e) {
            if ($e instanceof \Tymon\JWTAuth\Exceptions\TokenInvalidException) {
                return $this->apiResponse->error_response(200, 'Token Invalid', ['code' => 302, 'message' => 'Token Invalid']);
            } else if ($e instanceof \Tymon\JWTAuth\Exceptions\TokenExpiredException) {
                return $this->apiResponse->error_response(200, 'Token Expired', ['code' => 303, 'message' => 'Token Expired']);
            } else {
                return $this->apiResponse->error_response(200, 'Authorization Token not found', ['code' => 304, 'message' => 'Authorization Token not found']);
            }
        }
        return $next($request);
    }
}
