<?php


namespace App\Services;


use App\Models\Exam;
use App\Models\Question;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cache;

class QuestionService
{   public $question_per_set = 40 , $set_count = 10;
    public function create(Request $request){
        $question = Question::insert([
            'exam_id' => $request->exam_id,
            'question' => $request->question,
            'options' => json_encode($request->options),
            'correct_answer' => $request->correct_answer,
            'difficulty' => $request->difficulty

        ]);
        return $question;
    }
    public function update(Request $request){
        $exam = Question::where('id' , $request->id)->update([
            'question' => $request->question,
            'options' => json_encode($request->options),
            'correct_answer' => $request->correct_answer,
            'difficulty' => $request->difficulty
        ]);
        return $exam;
    }
    public function delete(Request $request){
        $id = $request->id;
        Question::where('id', $id)->delete();
    }
    public function get(Request $request){
        return Exam::find($request->id);
    }
    public function getQuestionsForExam(Request $request){
            $set_no = $request->set_no;
            $questio_set =  Cache::remember('question_set'.$set_no, 120, function () use ($set_no) {
                $total_question = Question::count();
                $starting_point = ($total_question/ $this->set_count)*($set_no - 1);
                $questions = Question::skip($starting_point)->take($this->question_per_set)->get();
                if(count($questions) < $this->question_per_set){
                    $need_extra = $this->question_per_set - count($questions);
                    $more_questions = Question::skip(0)->take($need_extra)->get();
                    $merge = $questions->merge($more_questions);
                    return self::cleanQuestions($merge);
                }
                return self::cleanQuestions($questions);
            });
            return $questio_set;

    }
    public static function cleanQuestions($questions){
        foreach ($questions as $question){
            $question->options = json_decode($question->options);
            $question->correct_answer = null;
        }
        return $questions;
    }

}
