<?php

use Illuminate\Http\Request;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::middleware('auth:api')->get('/user', function (Request $request) {
    return $request->user();
});

Route::group(['middleware' => 'jwt.verify'], function () {

    Route::get('/get-logged-in-user', 'Api\Auth\LoginController@getLoggedinUser');
    Route::post('/user-update', 'Api\UserController@update');
    Route::post('/change-password', 'Api\UserInfoController@updatePassword');
    Route::post('/change-image', 'Api\UserInfoController@updateProfileImage');
    Route::post('logout','Api\Auth\LoginController@logout');
    Route::get('/get-user-info','Api\UserController@getUserInfo');
    Route::post('/upload-video-for-exam-android', 'Api\ExamController@submitVideoForAndroid' );
});


//registration

Route::post('/registration', 'Api\Auth\RegisterController@registerUser');
Route::get('/get-university-list', 'Api\UniversityController@getUniversityList');
Route::get('/get-registration-user-types', 'Api\UserController@getRegistrationUserTypes');
Route::get('/get-admin-user-types', 'Api\UserController@getAdminUserTypes');


//About-Us-Apis


Route::post('/about-us/create', 'Api\AboutUsController@store');
Route::post('/about-us/update', 'Api\AboutUsController@update');
Route::post('/about-us/delete', 'Api\AboutUsController@delete');
Route::get('/about-us/index', 'Api\AboutUsController@index');

//Exam
Route::post('/exam/create', 'Api\ExamController@store');
Route::post('/exam/update', 'Api\ExamController@update');
Route::post('/exam/delete', 'Api\ExamController@delete');
Route::get('/exam/list', 'Api\ExamController@getList');
Route::get('/exam/get', 'Api\ExamController@get');
Route::post('/exam/submit-exam-paper', 'Api\ExamController@submitExamPaper');
Route::post('/exam/submit-exam-paper-for-android', 'Api\ExamController@submitExamPaperforAndriod');
Route::post('/video-upload-for-exam','Api\ExamController@submitVideo');
Route::post('/submit-video-data','Api\ExamController@submitVideoData');
Route::post('/submit-youtube-video-link','Api\ExamController@submitYoutubeVideoLink');
Route::post('/submit-drive-video-link','Api\ExamController@submitDriveVideoLink');
Route::post('/exam/check-video-exist','Api\ExamController@checkVideoExist');
//Exam ideo

Route::get('/video/get-unassigned-list','Api\VideoController@getUnassignedList');
Route::get('/video/get-assigned-list','Api\VideoController@getAssignedList');
Route::post('/video/get','Api\VideoController@get');
Route::post('/video/give-marks','Api\VideoController@giveMarks');

//Exam-Question
Route::post('/exam/question/create', 'Api\QuestionController@store');
Route::post('/exam/question/update', 'Api\QuestionController@update');
Route::post('/exam/question/delete', 'Api\QuestionController@delete');
Route::get('/exam/question/list', 'Api\QuestionController@getList');
Route::get('/exam/get-questions-for-exam', 'Api\QuestionController@getQuestionsForExam');


Route::post('/role/store', 'Api\RoleController@store');
Route::get('/get-all-role', 'Api\RoleController@index');
Route::post('/get-single-role-permissions', 'Api\RoleController@edit');



Route::post('/contact-us/create', 'Api\ContactUsController@store');
Route::post('/contact-us/update', 'Api\ContactUsController@update');
Route::post('/contact-us/delete', 'Api\ContactUsController@delete');
Route::get('/contact-us/index', 'Api\ContactUsController@index');
Route::get('/contact-us/make-contacted', 'Api\ContactUsController@makeContacted');


Route::post('login', 'Api\Auth\LoginController@login');
/*Route::post('login','Api\Auth\LoginController@login');*/



//User Api
Route::post('/user-create', 'Api\UserController@create');
Route::post('/user-delete', 'Api\UserController@delete');
Route::post('/user-show', 'Api\UserController@index');

//NoticeBoardApi

Route::post('/notice/create','Api\NoticeBoardController@store');
Route::post('/notice/update','Api\NoticeBoardController@update');
Route::post('/notice/delete','Api\NoticeBoardController@delete');
Route::post('/notice/index','Api\NoticeBoardController@getNotice');
Route::post('/notice/get-notice-list','Api\NoticeBoardController@getCategoryWiseNotice');
Route::get('/notice/get-notice','Api\NoticeBoardController@getSingleNotice');

//Gallary Api

Route::post('/gallary/create','Api\GallaryController@store');
Route::post('/gallary/update','Api\GallaryController@update');
Route::post('/gallary/delete','Api\GallaryController@delete');
Route::post('/gallary/index','Api\GallaryController@index');
Route::post('/gallary/all-photo','Api\GallaryController@getAllPhoto');



//admin approval

Route::get('/admin/unapproval-list','Api\UserController@upApproverlist');
Route::get('/admin/approval-list','Api\UserController@approverlist');
Route::get('/admin/get-admin-list','Api\UserController@getAdminList');
Route::post('/admin/approval','Api\UserController@approve');
Route::post('/admin/unapproval','Api\UserController@unapprove');
Route::post('/user-delete','Api\UserController@userDelete');

Route::post('/forgot-password','Api\UserInfoController@forgotPassword');
Route::post('/token-check','Api\UserInfoController@checkResetToken');
Route::post('/reset-password','Api\UserInfoController@resetPassword');



//Resend Email
Route::post('/resend-user-email','Api\Auth\RegisterController@ResendEmail');

//List Rendering
Route::post('/get-judge-list','Api\UserTypeRenderingController@getJudgeList');
Route::post('/get-sponsor-list','Api\UserTypeRenderingController@getSponsorList');
Route::post('/get-winner-list','Api\UserTypeRenderingController@getWinnerList');
Route::post('/get-supervisor-list','Api\UserTypeRenderingController@getSupervisorList');

Route::post('/get-home-page-data','Api\HomePageController@getHomePageData');


//Participant and Judges Api

Route::get('/get-participant-count','Api\UserInfoController@getParticipantCount');
Route::get('/get-judge-count','Api\UserInfoController@getJudgeCount');


Route::get('/zone/get', 'Api\ZoneController@get');
Route::get('/zone/get-active-zone', 'Api\ZoneController@getActiveZone');
Route::post('/zone/update', 'Api\ZoneController@update');
Route::post('/zone/create', 'Api\ZoneController@create');
Route::post('/zone/delete', 'Api\ZoneController@delete');

Route::post('/spnsor/create','Api\SponsorController@create');
Route::get('/spnsor/show','Api\SponsorController@index');

Route::get('/xl/download','Api\XLManagement@download');
Route::get('/result/download','Api\ResultController@download');

//Physical Audition

Route::get('/physical-audition/get','Api\PhysicalAuditionController@get');
Route::get('/physical-audition/get-assigned','Api\PhysicalAuditionController@getAssigned');
Route::post('/physical-audition/update','Api\PhysicalAuditionController@update');


Route::post('/result/get-user-result','Api\ResultController@get');
Route::post('/get-supervisor','Api\ResultController@supervisor');


